refnx
=====

[![Build Status](https://travis-ci.org/refnx/refnx.svg?branch=master)](https://travis-ci.org/refnx/refnx)
[![Build status](https://ci.appveyor.com/api/projects/status/gv6965vuqnuufx9u?svg=true)](https://ci.appveyor.com/project/andyfaff/refnx)
[![Documentation Status](https://readthedocs.org/projects/refnx/badge/?version=latest)](https://refnx.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/23189/refnx/refnx.svg)](https://zenodo.org/badge/latestdoi/23189/refnx/refnx)
[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/refnx/refnx-binder.git/master)

Neutron and X-ray reflectometry analysis in Python. Documentation at https://refnx.readthedocs.io.